Macro cmd_lib_cf::cmd_warn [−][src]
cmd_warn!() { /* proc-macro */ }Expand description
Logs a message at the warn level with interpolation support
cmd_warn!() { /* proc-macro */ }Logs a message at the warn level with interpolation support